@@ -9,6 +9,9 @@ from rest_framework_simplejwt.authentication import JWTAuthentication
 
 
 class JSONWebTokenBackend:
+    def __init__(self):
+        self.simple_jwt = JWTAuthentication()
+
     def authenticate(self, request=None, **kwargs):
         if request is None or getattr(request, "_jwt_token_auth", False):
             return None
